<?php

namespace Testprovider\Testpackage\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Testprovider\Testpackage\Http\Requests\TrainingmodelRequest;
use Testprovider\Testpackage\Models\Trainingmodel;

/**
 * Admin web controller class.
 */
class TrainingmodelWorkflowController extends BaseController
{

    /**
     * Workflow controller function for trainingmodel.
     *
     * @param Model   $trainingmodel
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TrainingmodelRequest $request, Trainingmodel $trainingmodel, $step)
    {

        try {

            $trainingmodel->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('testpackage::trainingmodel.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/trainingmodel/trainingmodel/' . $trainingmodel->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/trainingmodel/trainingmodel/' . $trainingmodel->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for trainingmodel.
     *
     * @param Model   $trainingmodel
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Trainingmodel $trainingmodel, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $trainingmodel->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('testpackage::trainingmodel.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('testpackage::admin.trainingmodel.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('testpackage::admin.trainingmodel.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('testpackage::admin.trainingmodel.message', $data)->render();

        }

    }
}
