<?php

namespace Testprovider\Testpackage\Policies;

use Litepie\User\Contracts\UserPolicy;
use Testprovider\Testpackage\Models\Trainingmodel;

class TrainingmodelPolicy
{

    /**
     * Determine if the given user can view the trainingmodel.
     *
     * @param UserPolicy $user
     * @param Trainingmodel $trainingmodel
     *
     * @return bool
     */
    public function view(UserPolicy $user, Trainingmodel $trainingmodel)
    {
        if ($user->canDo('testpackage.trainingmodel.view') && $user->isAdmin()) {
            return true;
        }

        return $trainingmodel->user_id == user_id() && $trainingmodel->user_type == user_type();
    }

    /**
     * Determine if the given user can create a trainingmodel.
     *
     * @param UserPolicy $user
     * @param Trainingmodel $trainingmodel
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('testpackage.trainingmodel.create');
    }

    /**
     * Determine if the given user can update the given trainingmodel.
     *
     * @param UserPolicy $user
     * @param Trainingmodel $trainingmodel
     *
     * @return bool
     */
    public function update(UserPolicy $user, Trainingmodel $trainingmodel)
    {
        if ($user->canDo('testpackage.trainingmodel.edit') && $user->isAdmin()) {
            return true;
        }

        return $trainingmodel->user_id == user_id() && $trainingmodel->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given trainingmodel.
     *
     * @param UserPolicy $user
     * @param Trainingmodel $trainingmodel
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Trainingmodel $trainingmodel)
    {
        return $trainingmodel->user_id == user_id() && $trainingmodel->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given trainingmodel.
     *
     * @param UserPolicy $user
     * @param Trainingmodel $trainingmodel
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Trainingmodel $trainingmodel)
    {
        if ($user->canDo('testpackage.trainingmodel.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given trainingmodel.
     *
     * @param UserPolicy $user
     * @param Trainingmodel $trainingmodel
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Trainingmodel $trainingmodel)
    {
        if ($user->canDo('testpackage.trainingmodel.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
