<?php

namespace Testprovider\Testpackage\Workflow;

use Testprovider\Testpackage\Models\Trainingmodel;
use Validator;

class TrainingmodelValidator
{

    /**
     * Determine if the given trainingmodel is valid for complete status.
     *
     * @param Trainingmodel $trainingmodel
     *
     * @return bool / Validator
     */
    public function complete(Trainingmodel $trainingmodel)
    {
        return Validator::make($trainingmodel->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given trainingmodel is valid for verify status.
     *
     * @param Trainingmodel $trainingmodel
     *
     * @return bool / Validator
     */
    public function verify(Trainingmodel $trainingmodel)
    {
        return Validator::make($trainingmodel->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given trainingmodel is valid for approve status.
     *
     * @param Trainingmodel $trainingmodel
     *
     * @return bool / Validator
     */
    public function approve(Trainingmodel $trainingmodel)
    {
        return Validator::make($trainingmodel->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given trainingmodel is valid for publish status.
     *
     * @param Trainingmodel $trainingmodel
     *
     * @return bool / Validator
     */
    public function publish(Trainingmodel $trainingmodel)
    {
        return Validator::make($trainingmodel->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given trainingmodel is valid for archive status.
     *
     * @param Trainingmodel $trainingmodel
     *
     * @return bool / Validator
     */
    public function archive(Trainingmodel $trainingmodel)
    {
        return Validator::make($trainingmodel->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given trainingmodel is valid for unpublish status.
     *
     * @param Trainingmodel $trainingmodel
     *
     * @return bool / Validator
     */
    public function unpublish(Trainingmodel $trainingmodel)
    {
        return Validator::make($trainingmodel->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
